@@ -1,5 +1,5 @@
-/* $Id: xio-pipe.c,v 1.22 2006/03/21 20:52:11 gerhard Exp $ */
-/* Copyright Gerhard Rieger 2001-2006 */
+/* source: xio-pipe.c */
+/* Copyright Gerhard Rieger 2001-2008 */
 /* Published under the GNU General Public License V.2, see file COPYING */
 
 /* this file contains the source for opening addresses of pipe type */
@@ -27,8 +27,8 @@ static int xioopen_fifo_unnamed(xiofile_t *sock, struct opt *opts) {
    int numleft;
    int result;
 
-   applyopts(-1, opts, PH_INIT);
    if (applyopts_single(&sock->stream, opts, PH_INIT) < 0)  return -1;
+   applyopts(-1, opts, PH_INIT);
 
    if (Pipe(filedes) != 0) {
       Error2("pipe(%p): %s", filedes, strerror(errno));
@@ -37,7 +37,7 @@ static int xioopen_fifo_unnamed(xiofile_t *sock, struct opt *opts) {
    /*0 Info2("pipe({%d,%d})", filedes[0], filedes[1]);*/
 
    sock->common.tag               = XIO_TAG_RDWR;
-   sock->stream.dtype             = DATA_PIPE;
+   sock->stream.dtype             = XIODATA_PIPE;
    sock->stream.fd                = filedes[0];
    sock->stream.para.bipipe.fdout = filedes[1];
    applyopts_cloexec(sock->stream.fd,                opts);
@@ -74,7 +74,7 @@ static int xioopen_fifo_unnamed(xiofile_t *sock, struct opt *opts) {
 }
 
 
-/* open a named pipe/fifo */
+/* open a named or unnamed pipe/fifo */
 static int xioopen_fifo(int argc, const char *argv[], struct opt *opts, int xioflags, xiofile_t *fd, unsigned groups, int dummy1, int dummy2, int dummy3) {
    const char *pipename = argv[1];
    int rw = (xioflags & XIO_ACCMODE);
@@ -96,8 +96,8 @@ static int xioopen_fifo(int argc, const char *argv[], struct opt *opts, int xiof
       Error2("%s: wrong number of parameters (%d instead of 1)", argv[0], argc-1);
    }
 
-   applyopts(-1, opts, PH_INIT);
    if (applyopts_single(&fd->stream, opts, PH_INIT) < 0)  return -1;
+   applyopts(-1, opts, PH_INIT);
 
    retropt_bool(opts, OPT_UNLINK_EARLY, &opt_unlink_early);
    applyopts(-1, opts, PH_EARLY);
