@@ -1,5 +1,5 @@
-/* $Id: xio-socket.c,v 1.45 2007/03/06 21:12:09 gerhard Exp $ */
-/* Copyright Gerhard Rieger 2001-2007 */
+/* source: xio-socket.c */
+/* Copyright Gerhard Rieger 2001-2008 */
 /* Published under the GNU General Public License V.2, see file COPYING */
 
 /* this file contains the source for socket related functions */
@@ -401,6 +401,10 @@ int xioopen_connect(struct single *xfd, struct sockaddr *us, size_t uslen,
 	 return result;
       }
 
+      if (dofork) {
+	 xiosetchilddied();	/* set SIGCHLD handler */
+      }
+
 #if WITH_RETRY
       if (dofork) {
 	 pid_t pid;
@@ -508,9 +512,37 @@ int _xioopen_dgram_sendto(/* them is already in xfd->peersa */
 static pid_t xio_waitingfor;
 static bool xio_hashappened;
 void xiosigaction_hasread(int signum, siginfo_t *siginfo, void *ucontext) {
+   pid_t pid;
+   int _errno;
+   int status = 0;
+   bool wassig = false;
    Debug5("xiosigaction_hasread(%d, {%d,%d,%d,"F_pid"}, )",
 	  signum, siginfo->si_signo, siginfo->si_errno, siginfo->si_code,
 	  siginfo->si_pid);
+   _errno = errno;
+   do {
+      pid = Waitpid(-1, &status, WNOHANG);
+      if (pid == 0) {
+	 Msg(wassig?E_INFO:E_WARN,
+	     "waitpid(-1, {}, WNOHANG): no child has exited");
+	 Info("childdied() finished");
+	 errno = _errno;
+	 return;
+      } else if (pid < 0 && errno == ECHILD) {
+	 Msg1(wassig?E_INFO:E_WARN,
+	      "waitpid(-1, {}, WNOHANG): %s", strerror(errno));
+	 Info("childdied() finished");
+	 errno = _errno;
+	 return;
+      }
+      wassig = true;
+      if (pid < 0) {
+	 Warn2("waitpid(-1, {%d}, WNOHANG): %s", status, strerror(errno));
+	 Info("childdied() finished");
+	 errno = _errno;
+	 return;
+      }
+   } while (1);
    if (xio_waitingfor == siginfo->si_pid) {
       xio_hashappened = true;
    }
@@ -554,29 +586,6 @@ int _xioopen_dgram_recvfrom(struct single *xfd, int xioflags,
 
    if (applyopts_single(xfd, opts, PH_INIT) < 0)  return STAT_NORETRY;
 
-#if 1
-   if (dofork) {
-#if HAVE_SIGACTION
-      struct sigaction act;
-      memset(&act, 0, sizeof(struct sigaction));
-      act.sa_flags   = SA_NOCLDSTOP|SA_RESTART
-#ifdef SA_NOMASK
-	 |SA_NOMASK
-#endif
-	 ;
-      act.sa_handler = childdied;
-      if (Sigaction(SIGCHLD, &act, NULL) < 0) {
-	 /*! man does not say that errno is defined */
-	 Warn2("sigaction(SIGCHLD, %p, NULL): %s", childdied, strerror(errno));
-      }
-#else /* HAVE_SIGACTION */
-      if (Signal(SIGCHLD, childdied) == SIG_ERR) {
-	 Warn2("signal(SIGCHLD, %p): %s", childdied, strerror(errno));
-      }
-#endif /* !HAVE_SIGACTION */
-   }
-#endif /* 1 */
-
    if ((xfd->fd = Socket(pf, socktype, proto)) < 0) {
       Msg4(level,
 	   "socket(%d, %d, %d): %s", pf, socktype, proto, strerror(errno));
