@@ -1,5 +1,5 @@
-/* $Id: xiohelp.c,v 1.19 2007/02/05 21:07:07 gerhard Exp $ */
-/* Copyright Gerhard Rieger 2001-2007 */
+/* source: xiohelp.c */
+/* Copyright Gerhard Rieger 2001-2008 */
 /* Published under the GNU General Public License V.2, see file COPYING */
 
 /* this file contains the source for the help function */
@@ -25,7 +25,7 @@ static const char *optiontypenames[] = {
 	"OFF_T",	"OFF64_T",
 #if HAVE_STRUCT_IP_MREQN
 					"STRUCT-IP_MREQN",
-#elif HAVE_STRUCT_IP_MREQN
+#elif HAVE_STRUCT_IP_MREQ
 					"STRUCT-IP_MREQ",
 #endif
 							"IP4NAME",
