@@ -1,5 +1,5 @@
-/* $Id: xioshutdown.c,v 1.20 2006/05/06 14:21:02 gerhard Exp $ */
-/* Copyright Gerhard Rieger 2001-2006 */
+/* source: xioshutdown.c */
+/* Copyright Gerhard Rieger 2001-2007 */
 /* Published under the GNU General Public License V.2, see file COPYING */
 
 /* this is the source of the extended shutdown function */
@@ -33,12 +33,12 @@ int xioshutdown(xiofile_t *sock, int how) {
       }
 
 #if WITH_OPENSSL
-   } else if (sock->stream.dtype == DATA_OPENSSL) {
+   } else if ((sock->stream.dtype & XIODATA_MASK) == XIODATA_OPENSSL) {
       sycSSL_shutdown (sock->stream.para.openssl.ssl);
-      /*! */
+      /*! what about half/full close? */
 #endif /* WITH_OPENSSL */
 
-   } else if (sock->stream.dtype == DATA_PIPE) {
+   } else if ((sock->stream.dtype & XIODATA_MASK) == XIODATA_PIPE) {
       if ((how+1)&1) {
 	 if (Close(sock->stream.fd) < 0) {
 	    Info2("close(%d): %s",
@@ -52,7 +52,7 @@ int xioshutdown(xiofile_t *sock, int how) {
 	 } 
       }
       
-   } else if (sock->stream.dtype == DATA_2PIPE) {
+   } else if ((sock->stream.dtype & XIODATA_MASK) == XIODATA_2PIPE) {
       if ((how+1)&1) {
 	 if (Close(sock->stream.fd) < 0) {
 	    Info2("close(%d): %s",
@@ -98,7 +98,7 @@ int xioshutdown(xiofile_t *sock, int how) {
 	 }
 	 Alarm(0);
       }
-   } else if (sock->stream.dtype == DATA_RECVFROM) {
+   } else if ((sock->stream.dtype & XIODATA_MASK) == XIODATA_RECVFROM) {
       if (how >= 1) {
 	 if (Close(sock->stream.fd) < 0) {
 	    Info2("close(%d): %s",
